@@ -18,7 +18,7 @@ use Template::Provider;
 use IPC::Open2;
 use base qw/App::TemplateCMD::Command/;
 
-our $VERSION     = version->new('0.5.8');
+our $VERSION     = version->new('0.5.9');
 our @EXPORT_OK   = qw//;
 our %EXPORT_TAGS = ();
 
@@ -32,7 +32,7 @@ sub process {
 
     my $out = '';
     $cmd->{template}->process( $template, $args, \$out );
-    warn  $cmd->{template}->error . "\n" if $cmd->{template}->error;
+    warn  $cmd->{template}->error . "\n" if $cmd->{template}->error && $cmd->{template}->error !~ /^file error - .*: not a file$/;
 
     if (!$out) {
         my @files = uniq sort map {$_->{file}} $cmd->list_templates();
@@ -41,7 +41,7 @@ sub process {
 
         if (@templates) {
             $cmd->{template}->process( $templates[0], $args, \$out );
-            warn  $cmd->{template}->error . "\n" if $cmd->{template}->error;
+            warn  $cmd->{template}->error . "\n" if $cmd->{template}->error && $cmd->{template}->error !~ /^file error - .*: not a file$/;
         }
     }
 
@@ -119,7 +119,7 @@ App::TemplateCMD::Command::Print - Prints a parsed template out to screen or fil
 
 =head1 VERSION
 
-This documentation refers to App::TemplateCMD::Command::Print version 0.5.8.
+This documentation refers to App::TemplateCMD::Command::Print version 0.5.9.
 
 =head1 SYNOPSIS
 
